const char * cockpit_webresponse_fail_html_text =
 "<!DOCTYPE html>\n"
 "<html>\n"
 "<head>\n"
 "    <title>@@message@@</title>\n"
 "    <meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\">\n"
 "    <meta name=\"viewport\" content=\"width=device-width, initial-scale=1.0\">\n"
 "    <style>\n"
 "        :root {\n"
 "            --pf-t--global--background--color--secondary--default: #f2f2f2;\n"
 "            --pf-v6-c-page__main-container--BackgroundColor: #ffffff;\n"
 "            --pf-v6-c-empty-state__icon--Color: #707070;\n"
 "            --pf-t--global--text--color--regular: #151515;\n"
 "        }\n"
 "        :root:where(.pf-v6-theme-dark) {\n"
 "            --pf-t--global--background--color--secondary--default: #151515;\n"
 "            --pf-v6-c-page__main-container--BackgroundColor: #292929;\n"
 "            --pf-v6-c-empty-state__icon--Color: #a3a3a3;\n"
 "            --pf-t--global--text--color--regular: #ffffff;\n"
 "        }\n"
 "        html {\n"
 "            height: 100%;\n"
 "            display: block;\n"
 "        }\n"
 "        body {\n"
 "            margin: 0;\n"
 "            font-family: \"Red Hat Display\", \"RedHatDisplay\", \"Noto Sans Arabic\", \"Noto Sans Hebrew\", \"Noto Sans JP\", \"Noto Sans KR\", \"Noto Sans Malayalam\", \"Noto Sans SC\", \"Noto Sans TC\", \"Noto Sans Thai\", Helvetica, Arial, sans-serif;\n"
 "            line-height: 1.3;\n"
 "            color: var(--pf-t--global--text--color--regular);\n"
 "            background: var(--pf-t--global--background--color--secondary--default);\n"
 "\n"
 "        }\n"
 "        img {\n"
 "            border: 0;\n"
 "            vertical-align: middle;\n"
 "        }\n"
 "        h1 {\n"
 "            font-size: 1.25rem;\n"
 "            font-weight: 500;\n"
 "        }\n"
 "        @font-face {\n"
 "            font-family: \"Red Hat Display\";\n"
 "            font-style: normal;\n"
 "            font-weight: 400 700;\n"
 "            src: url(\"fonts/RedHatDisplay/RedHatDisplayVF.woff2\") format(\"woff2-variations\");\n"
 "            font-display: fallback;\n"
 "        }\n"
 "        .blank-slate-pf {\n"
 "            text-align: center;\n"
 "            padding: 90px 120px;\n"
 "        }\n"
 "        .pf-v6-svg {\n"
 "            width: 1em;\n"
 "            height: 1em;\n"
 "            vertical-align: -0.125em;\n"
 "            font-size: 3.5rem;\n"
 "            color: var(--pf-v6-c-empty-state__icon--Color);\n"
 "            margin-block-end: 1.5rem;\n"
 "        }\n"
 "        .pf-v6-c-page__main-container {\n"
 "            border-radius: 16px;\n"
 "            background: var(--pf-v6-c-page__main-container--BackgroundColor);\n"
 "            margin-inline: 1.5rem;\n"
 "            block-size: 100%;\n"
 "        }\n"
 "    </style>\n"
 "    <script>\n"
 "        /*\n"
 "        * Copyright (C) 2022 Red Hat, Inc.\n"
 "        * SPDX-License-Identifier: LGPL-2.1-or-later\n"
 "        */\n"
 "\n"
 "        function debug(...args) {\n"
 "            if (window.debugging == \"all\" || window.debugging?.includes(\"style\")) {\n"
 "                console.debug([`cockpit-dark-theme: ${document.documentElement.id}:`, ...args].join(\" \"));\n"
 "            }\n"
 "        }\n"
 "\n"
 "        function changeDarkThemeClass(documentElement, dark_mode) {\n"
 "            debug(`Setting cockpit theme to ${dark_mode ? \"dark\" : \"light\"}`);\n"
 "\n"
 "            if (dark_mode) {\n"
 "                documentElement.classList.add('pf-v6-theme-dark');\n"
 "            } else {\n"
 "                documentElement.classList.remove('pf-v6-theme-dark');\n"
 "            }\n"
 "        }\n"
 "\n"
 "        function _setDarkMode(_style) {\n"
 "            const style = _style || localStorage.getItem('shell:style') || 'auto';\n"
 "            let dark_mode;\n"
 "            // If a user set's an explicit theme, ignore system changes.\n"
 "            if ((window.matchMedia?.('(prefers-color-scheme: dark)').matches && style === \"auto\") || style === \"dark\") {\n"
 "                dark_mode = true;\n"
 "            } else {\n"
 "                dark_mode = false;\n"
 "            }\n"
 "            changeDarkThemeClass(document.documentElement, dark_mode);\n"
 "        }\n"
 "\n"
 "        window.addEventListener(\"storage\", event => {\n"
 "            if (event.key === \"shell:style\") {\n"
 "                debug(`Storage element 'shell:style' changed from  ${event.oldValue} to ${event.newValue}`);\n"
 "\n"
 "                _setDarkMode();\n"
 "            }\n"
 "        });\n"
 "\n"
 "        // When changing the theme from the shell switcher the localstorage change will not fire for the same page (aka shell)\n"
 "        // so we need to listen for the event on the window object.\n"
 "        window.addEventListener(\"cockpit-style\", event => {\n"
 "            if (event instanceof CustomEvent) {\n"
 "                const style = event.detail.style;\n"
 "                debug(`Event received from shell with 'cockpit-style'  ${style}`);\n"
 "\n"
 "                _setDarkMode(style);\n"
 "            }\n"
 "        });\n"
 "\n"
 "        window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', () => {\n"
 "            debug(`Operating system theme preference changed to ${window.matchMedia?.('(prefers-color-scheme: dark)').matches ? \"dark\" : \"light\"}`);\n"
 "            _setDarkMode();\n"
 "        });\n"
 "\n"
 "        _setDarkMode();\n"
 "    </script>\n"
 "</head>\n"
 "<body>\n"
 "    <div class=\"pf-v6-c-page__main-container\">\n"
 "        <div class=\"blank-slate-pf\">\n"
 "            <svg class=\"pf-v6-svg\" viewBox=\"0 0 512 512\" fill=\"currentColor\" aria-hidden=\"true\" role=\"img\" width=\"1em\" height=\"1em\"><path d=\"M504 256c0 136.997-111.043 248-248 248S8 392.997 8 256C8 119.083 119.043 8 256 8s248 111.083 248 248zm-248 50c-25.405 0-46 20.595-46 46s20.595 46 46 46 46-20.595 46-46-20.595-46-46-46zm-43.673-165.346l7.418 136c.347 6.364 5.609 11.346 11.982 11.346h48.546c6.373 0 11.635-4.982 11.982-11.346l7.418-136c.375-6.874-5.098-12.654-11.982-12.654h-63.383c-6.884 0-12.356 5.78-11.981 12.654z\"></path></svg>\n"
 "            <h1>@@message@@</h1>\n"
 "        </div>\n"
 "    </div>\n"
 "</body>\n"
 "</html>\n"
 ;
